DialogUtilsCore class

Constructors

DialogUtilsCore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dismiss<T>({SmartStatus status = SmartStatus.smart, String? tag, T? result, bool force = false}) Future<void>
关闭当前dialog
show<T>({required Widget builder(BuildContext), bool clickMaskDismiss = true, bool? usePenetrate, bool useAnimation = true, bool debounce = true, bool hideMaskColor = false, BuildContext? bindWidget, SmartDialogController? controller, Alignment alignment = Alignment.center, SmartAnimationType? animationType, Color? maskColor, VoidCallback? onDismiss}) Future<T?>
builder:自定义 dialog