theme_color/theme_color library

Classes

NeutralColor
Defines a single color as well a color swatch with ten shades of the color. same as AntColor but has 3 more shades of the color.
ThemeColor
Defines a single color as well a color swatch with ten shades of the color.

Functions

hexColor(String hexColor) Color
A color that is represented in hexadecimal format.