BaseInkWell class

Inheritance

Constructors

BaseInkWell({Key? key, Widget? child, void onTap()?, void onDoubleTap()?, void onLongPress()?, void onTapDown(TapDownDetails)?, void onTapUp(TapUpDetails)?, void onTapCancel()?, void onSecondaryTap()?, void onSecondaryTapUp(TapUpDetails)?, void onSecondaryTapDown(TapDownDetails)?, void onSecondaryTapCancel()?, void onHighlightChanged(bool)?, void onHover(bool)?, MouseCursor? mouseCursor, Color? focusColor, Color? hoverColor, Color? highlightColor, WidgetStateProperty<Color?>? overlayColor, Color? splashColor, InteractiveInkFeatureFactory? splashFactory, double? radius, BorderRadius? borderRadius, ShapeBorder? customBorder, bool enableFeedback = true, bool excludeFromSemantics = false, FocusNode? focusNode, bool canRequestFocus = true, void onFocusChange(bool)?, bool autofocus = false, WidgetStatesController? statesController, Duration? hoverDuration})
const

Properties

autofocus bool
final
borderRadius BorderRadius?
final
canRequestFocus bool
final
child Widget?
final
customBorder ShapeBorder?
final
enableFeedback bool
final
excludeFromSemantics bool
final
focusColor Color?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
final
hoverColor Color?
final
hoverDuration Duration?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mouseCursor MouseCursor?
final
onDoubleTap → void Function()?
final
onFocusChange → void Function(bool)?
final
onHighlightChanged → void Function(bool)?
final
onHover → void Function(bool)?
final
onLongPress → void Function()?
final
onSecondaryTap → void Function()?
final
onSecondaryTapCancel → void Function()?
final
onSecondaryTapDown → void Function(TapDownDetails)?
final
onSecondaryTapUp → void Function(TapUpDetails)?
final
onTap → void Function()?
final
onTapCancel → void Function()?
final
onTapDown → void Function(TapDownDetails)?
final
onTapUp → void Function(TapUpDetails)?
final
overlayColor WidgetStateProperty<Color?>?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color?
final
splashFactory InteractiveInkFeatureFactory?
final
statesController WidgetStatesController?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited