ToastUtilsCore class
Constructors
- ToastUtilsCore()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ToastUtilsCore
-
no setter
Static Methods
-
dismiss(
) → Future< void> - 关闭当前toast
-
dismissAll(
) → Future< void> - 关闭全部toast
-
showToast(
String message, {Duration? duration, bool clickMaskDismiss = false, bool usePenetrate = true, Color maskColor = Colors.transparent, Alignment alignment = Alignment.center, SmartToastType displayType = SmartToastType.onlyRefresh}) → Future< void> - showToast