IRouterAbstract class abstract
- Implementers
Constructors
Properties
-
allRoutes
↔ List<
FlutterRouter> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
getter/setter pair
-
observers
↔ List<
NavigatorObserver> ? -
getter/setter pair
-
redirect
↔ FutureOr<
String?> Function(BuildContext, GoRouterState)? -
getter/setter pair
-
routes
↔ List<
FlutterRouter> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateRoutes(
) → GoRouter - 根据自定义路由FlutterRouter 组装成GoRoute
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited